## Typing stubs for click-log

This is a [PEP 561](https://peps.python.org/pep-0561/)
type stub package for the [`click-log`](https://github.com/click-contrib/click-log) package.
It can be used by type-checking tools like
[mypy](https://github.com/python/mypy/),
[pyright](https://github.com/microsoft/pyright),
[pytype](https://github.com/google/pytype/),
[Pyre](https://pyre-check.org/),
PyCharm, etc. to check code that uses `click-log`. This version of
`types-click-log` aims to provide accurate annotations for
`click-log==0.4.*`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/click-log`](https://github.com/python/typeshed/tree/main/stubs/click-log)
directory.

This package was tested with
mypy 1.15.0,
pyright 1.1.399,
and pytype 2024.10.11.
It was generated from typeshed commit
[`6d0402cb0363bd410200e285882d0586e6c728b5`](https://github.com/python/typeshed/commit/6d0402cb0363bd410200e285882d0586e6c728b5).